diff -urN -X dontdiff linux/drivers/block/rd.c 2328-super/drivers/block/rd.c
--- linux/drivers/block/rd.c	Mon Oct 25 16:59:32 1999
+++ 2328-super/drivers/block/rd.c	Wed Nov 17 12:50:50 1999
@@ -339,6 +339,24 @@
 	block_fsync	/* fsync */ 
 };
 
+#ifdef MODULE
+#define rd_init init_module
+
+/* Before freeing the module, invalidate all of the protected buffers! */
+void cleanup_module(void)
+{
+	int i;
+
+	for (i = 0 ; i < NUM_RAMDISKS; i++)
+		invalidate_buffers(MKDEV(MAJOR_NR, i));
+
+	unregister_blkdev( MAJOR_NR, "ramdisk" );
+	blk_dev[MAJOR_NR].request_fn = 0;
+}
+
+#endif  /* MODULE */
+
+
 /* This is the registration and initialization section of the RAM disk driver */
 int __init rd_init(void)
 {
@@ -380,34 +398,10 @@
 
 /* loadable module support */
 
-#ifdef MODULE
-
 MODULE_PARM     (rd_size, "1i");
 MODULE_PARM_DESC(rd_size, "Size of each RAM disk in kbytes.");
 MODULE_PARM     (rd_blocksize, "i");
 MODULE_PARM_DESC(rd_blocksize, "Blocksize of each RAM disk in bytes.");
-
-int init_module(void)
-{
-	int error = rd_init();
-	if (!error)
-		printk(KERN_INFO "RAMDISK: Loaded as module.\n");
-	return error;
-}
-
-/* Before freeing the module, invalidate all of the protected buffers! */
-void cleanup_module(void)
-{
-	int i;
-
-	for (i = 0 ; i < NUM_RAMDISKS; i++)
-		invalidate_buffers(MKDEV(MAJOR_NR, i));
-
-	unregister_blkdev( MAJOR_NR, "ramdisk" );
-	blk_dev[MAJOR_NR].request_fn = 0;
-}
-
-#endif  /* MODULE */
 
 /* End of non-loading portions of the RAM disk driver */
 
diff -urN -X dontdiff linux/fs/super.c 2328-super/fs/super.c
--- linux/fs/super.c	Fri Nov 12 12:36:13 1999
+++ 2328-super/fs/super.c	Wed Nov 17 10:06:40 1999
@@ -567,7 +567,6 @@
 	if (!type->read_super(s, data, silent))
 		goto out_fail;
 	s->s_dev = dev; /* N.B. why do this again?? */
-	s->s_rd_only = 0;
 	s->s_type = type;
 out:
 	return s;
diff -urN -X dontdiff linux/fs/udf/super.c 2328-super/fs/udf/super.c
--- linux/fs/udf/super.c	Fri Nov 12 12:29:47 1999
+++ 2328-super/fs/udf/super.c	Wed Nov 17 10:20:02 1999
@@ -1366,7 +1366,6 @@
 
 	/* Fill in the rest of the superblock */
 	sb->s_op = &udf_sb_ops;
-	sb->s_time = 0;
 	sb->dq_op = NULL;
 	sb->s_dirt = 0;
 	sb->s_magic = UDF_SUPER_MAGIC;
diff -urN -X dontdiff linux/include/linux/fs.h 2328-super/include/linux/fs.h
--- linux/include/linux/fs.h	Fri Nov 12 19:28:05 1999
+++ 2328-super/include/linux/fs.h	Wed Nov 17 10:41:46 1999
@@ -543,14 +543,12 @@
 	unsigned long		s_blocksize;
 	unsigned char		s_blocksize_bits;
 	unsigned char		s_lock;
-	unsigned char		s_rd_only;
 	unsigned char		s_dirt;
 	struct file_system_type	*s_type;
 	struct super_operations	*s_op;
 	struct dquot_operations	*dq_op;
 	unsigned long		s_flags;
 	unsigned long		s_magic;
-	unsigned long		s_time;
 	struct dentry		*s_root;
 	wait_queue_head_t	s_wait;
 
